@@ -1,10 +1,10 @@
 import uuid
 
 import tagulous.models
-from bx_py_utils.models.timetracking import TimetrackingBaseModel
+from bx_django_utils.models.timetracking import TimetrackingBaseModel
 from django.conf import settings
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class BaseModel(TimetrackingBaseModel):
