@@ -6,7 +6,7 @@ from bx_django_utils.filename import clean_filename
 from ckeditor_uploader.fields import RichTextUploadingField
 from django.db import models
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django_tools.serve_media_app.models import user_directory_path
 
 from inventory.models.base import BaseItemAttachmentModel, BaseModel
