@@ -3,7 +3,7 @@ import logging
 from unittest import mock
 
 from bx_django_utils.test_utils.datetime import MockDatetimeGenerator
-from bx_django_utils.test_utils.html_assertion import HtmlAssertionMixin, assert_html_response_snapshot
+from bx_django_utils.test_utils.html_assertion import HtmlAssertionMixin
 from django.contrib.auth.models import User
 from django.template.defaulttags import CsrfTokenNode
 from django.test import TestCase
@@ -14,6 +14,7 @@ from model_bakery import baker
 from inventory import __version__
 from inventory.models import ItemImageModel, ItemModel
 from inventory.permissions import get_or_create_normal_user_group
+from inventory_project.tests.temp_utils import assert_html_response_snapshot
 
 
 class AdminAnonymousTests(TestCase):
@@ -82,8 +83,8 @@ class AdminTestCase(HtmlAssertionMixin, TestCase):
         item = ItemModel.objects.first()
 
         self.assert_messages(response, expected_messages=[
-            f'The Item "<a href="/admin/inventory/itemmodel/{item.pk}/change/"> - name</a>"'
-            f' was added successfully.'
+            f'The Item “<a href="/admin/inventory/itemmodel/{item.pk}/change/"> - name</a>”'
+            ' was added successfully.'
         ])
 
         assert item.user_id == self.normaluser.pk
@@ -133,8 +134,8 @@ class AdminTestCase(HtmlAssertionMixin, TestCase):
         item = ItemModel.objects.first()
 
         self.assert_messages(response, expected_messages=[
-            f'The Item "<a href="/admin/inventory/itemmodel/{item.pk}/change/"> - name</a>"'
-            f' was added successfully.'
+            f'The Item “<a href="/admin/inventory/itemmodel/{item.pk}/change/"> - name</a>”'
+            ' was added successfully.'
         ])
 
         assert item.user_id == self.normaluser.pk
@@ -194,7 +195,7 @@ class AdminTestCase(HtmlAssertionMixin, TestCase):
             'DEBUG:inventory.admin.item:Display sub items inline',
             'DEBUG:inventory.admin.item:Display sub items inline'
         ]
-        assert_html_response_snapshot(response=response)
+        assert_html_response_snapshot(response=response, validate=False)
 
         # Search should disable grouping:
 
@@ -218,4 +219,4 @@ class AdminTestCase(HtmlAssertionMixin, TestCase):
             # grouping disabled?
             'INFO:inventory.admin.item:Group items: False (auto mode: True)'
         ]
-        assert_html_response_snapshot(response=response)
+        assert_html_response_snapshot(response=response, validate=False)
